@@ -40,12 +40,12 @@ def test_web_hook_text_bot_standard_message():
     assert execution == {
                 'statusCode': 200,
                 'headers': {'Content-Type': 'application/json'},
-                'body': {
+                'body': json.dumps({
                     'method': 'sendMessage',
-                    'text': '"ping"',
+                    'text': 'ping',
                     'chat_id': web_hook_text_bot.input_message.chat_id,
                     'reply_to_message_id': 456
-                }
+                })
             }
 
 
@@ -69,11 +69,11 @@ def test_web_hook_text_bot_case_edited_message():
     assert execution == {
                 'statusCode': 200,
                 'headers': {'Content-Type': 'application/json'},
-                'body': {
+                'body': json.dumps({
                     'method': 'sendMessage',
-                    'text': '"pong"',
+                    'text': 'pong',
                     'chat_id': web_hook_text_bot.input_message.chat_id
-                }
+                })
             }
 
 
@@ -121,9 +121,9 @@ def test_web_hook_text_bot_case_run_exception():
     assert execution == {
         'statusCode': 200,
         'headers': {'Content-Type': 'application/json'},
-        'body': {
+        'body': json.dumps({
             'method': 'sendMessage',
-            'text': '"An error occurred: division by zero"',
+            'text': 'An error occurred: division by zero',
             'chat_id': web_hook_text_bot.input_message.chat_id
-        }
+        })
     }
